# Changelog
## 0.1.7- Add pytest and mypy tool configuration to pyproject.toml

## 0.1.6

- Add basic import test

## 0.1.5

- Add Development section to README

## 0.1.2

- Update project URLs in pyproject.toml

## 0.1.1

- Add Homepage, Changelog URLs to pyproject.toml

## 0.1.2

- Update project URLs in pyproject.toml

## 0.1.1

- Add project URLs to pyproject.toml

## 0.1.0 (2026-03-10)

- Initial release
